mysql.stmt.bind_in.In_Set

Package mysql :: Package stmt :: Module bind_in :: Class In_Set |
[hide private]
[frames] | no frames]

# Class In_Set

    object --+
             |
    Input_Bind --+
                 |
    Base_In_String --+
                     |
            In_Varchar --+
                         |
                        In_Set

SET input binding.

- `who`: The object from which to read the value.
- `what`: The name of the parameter in the object to read.
- `max_size`: The maximum size of the string. Attempting to input a string larger than this will raise `OverflowError` in the call to `execute`.

The value may be:

- A string.
- A number (will be converted with `str()`).
- A dictionary, which will result in a comma-separated list of keys.
- A set, which will result in a comma-separated list of values.
- An object with a `keys` method, which will result in a comma seperated list of values from that method.

Instance Methods | [hide private]
`` | __new__(T, S, ...) Returns a new object with type S, a subtype of T...
Inherited from `Base_In_String`: `__init__` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
`` | __pyx_vtable__ = `<PyCObject object at 0x852e548>`

Instance Variables | [hide private]
Inherited from `Base_In_String` (private): `_value` Inherited from `Input_Bind` (private): `_buffer`, `_buffer_length`, `_buffer_type`, `_is_null`, `_is_unsigned`, `_length`, `_what`, `_who`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __new__(T, S, ...) |
    Returns:
        a new object with type S, a subtype of T
Overrides: In_Varchar.__new__

Class Variable Details | [hide private]

    ### __pyx_vtable__ Value:
        <PyCObject object at 0x852e548>